@@ -1,3 +1,4 @@
+import json
 import os
 import platform
 import re
@@ -83,7 +84,7 @@ class Notifier:
             "query_stats": kwargs.get("query_stats", True),
             "queue_stats": kwargs.get("queue_stats", True),
             "max_backlog_size": kwargs.get("max_backlog_size", 100),
-            "backlog_enabled": kwargs.get("backlog_enabled", True),
+            "backlog_enabled": kwargs.get("backlog_enabled", False),
             "error_host": host,
             "apm_host": host,
         }
@@ -253,8 +254,8 @@ class Notifier:
             return notice
 
         self._rate_limit_reset = time.time() + delay
-
-        notice["error"] = _ERR_IP_RATE_LIMITED
+        data = json.loads(resp.read().decode("utf-8"))
+        notice["error"] = data['message']
         return notice
 
     def notify(self, err):
