@@ -1,16 +1,13 @@
 import re
 import warnings
-import pytest
-import time
 from urllib.error import URLError
 
-import requests
-import werkzeug
 from pybrake.notifier import Notifier
 from pybrake.notice import jsonify_notice
 from pybrake.utils import time_trunc_minute
-from .test_helper import (get_exception, get_nested_exception,
-                          get_exception_in_cython, build_notice_from_str)
+from .test_helper import (
+    get_exception, get_nested_exception, get_exception_in_cython,
+    build_notice_from_str, MockResponse)
 
 
 def test_build_notice_from_exception():
@@ -32,13 +29,13 @@ def test_build_notice_from_exception():
     frame = backtrace[0]
     assert frame["file"] == "/PROJECT_ROOT/tests/test_helper.py"
     assert frame["function"] == "get_exception"
-    assert frame["line"] == 6
+    assert frame["line"] == 7
     assert frame["code"] == {
-        4: "def get_exception():",
-        5: "    try:",
-        6: '        raise ValueError("hello")',
-        7: "    except ValueError as err:",
-        8: "        return err",
+        5: "def get_exception():",
+        6: "    try:",
+        7: '        raise ValueError("hello")',
+        8: "    except ValueError as err:",
+        9: "        return err",
     }
 
     context = notice["context"]
@@ -90,7 +87,7 @@ def test_build_notice_from_nested_exception():
     frame = backtrace[0]
     assert frame["file"] == "/PROJECT_ROOT/tests/test_helper.py"
     assert frame["function"] == "get_nested_exception"
-    assert frame["line"] == 51
+    assert frame["line"] == 52
 
     error = errors[1]
     assert error["type"] == "ValueError"
@@ -102,7 +99,7 @@ def test_build_notice_from_nested_exception():
     frame = backtrace[0]
     assert frame["file"] == "/PROJECT_ROOT/tests/test_helper.py"
     assert frame["function"] == "get_exception"
-    assert frame["line"] == 6
+    assert frame["line"] == 7
 
 
 def test_build_notice_from_str():
@@ -122,13 +119,13 @@ def test_build_notice_from_str():
     frame = backtrace[0]
     assert frame["file"] == "/PROJECT_ROOT/tests/test_helper.py"
     assert frame["function"] == "build_notice_from_str"
-    assert frame["line"] == 12
+    assert frame["line"] == 13
     assert frame["code"] == {
-        10: "",
-        11: "def build_notice_from_str(notifier, s):",
-        12: "    return notifier.build_notice(s)",
-        13: "",
+        11: "",
+        12: "def build_notice_from_str(notifier, s):",
+        13: "    return notifier.build_notice(s)",
         14: "",
+        15: "",
     }
 
 
@@ -313,7 +310,13 @@ def _test_full_queue():
     assert notice["error"] == "queue is full"
 
 
-def _test_rate_limited():
+def test_rate_limited(mocker):
+    resp = MockResponse(resp_data='{"message": "test"}'.encode("utf-8"),
+                        code=429, headers={'X-RateLimit-Delay': 100})
+    mocker.patch(
+        "urllib.request.urlopen",
+        return_value=resp
+    )
     notifier = Notifier()
 
     for _ in range(101):
@@ -342,8 +345,12 @@ def test_error_notifications_disabled():
     assert notice["error"] == "error notifications are disabled"
 
 
-def test_notifier_with_backlog():
-    notifier = Notifier()
+def test_notifier_with_backlog(mocker):
+    mocker.patch(
+        "pybrake.backlog.Backlog.send",
+        return_value=None
+    )
+    notifier = Notifier(backlog_enabled=True)
 
     err = get_nested_exception()
     notice = notifier.build_notice(err)
